Developer reference
===================

.. note::

  As of June 2023, the documentation of *Black classes* and *Black exceptions*
  has been updated to the latest available version.

  The documentation of *Black functions* is quite outdated and has been neglected. Many
  functions worthy of inclusion aren't documented. Contributions are appreciated!

*Contents are subject to change.*

.. toctree::
   :maxdepth: 2

   reference_classes
   reference_functions
   reference_exceptions
